@@ -8,7 +8,7 @@ use warnings;
 use Carp;
 use Exporter qw{ import };
 
-our $VERSION = '0.008_01';
+our $VERSION = '0.009_01';
 
 our %EXPORT_TAGS = (
     FILE_		=> [ qw{
@@ -167,7 +167,6 @@ we are eventually going to pass it to the C<utime()> built-in.
 
 This class has the following attributes:
 
-
 =head1 SEE ALSO
 
 <<< replace or remove boilerplate >>>
@@ -175,7 +174,8 @@ This class has the following attributes:
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Win32API-File-Time/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -183,7 +183,7 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2017, 2019 by Thomas R. Wyant, III
+Copyright (C) 2016-2017, 2019-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
